@@ -11,6 +11,7 @@
 #include "emailquery.h"
 #include "resultiterator_p.h"
 #include "../search/email/agepostingsource.h"
+#include "akonadi_search_pim_debug.h"
 
 #include <QStandardPaths>
 #include <QRegularExpression>
@@ -39,18 +40,15 @@ public:
     QString subjectMatchString;
     QString bodyMatchString;
 
-    EmailQuery::OpType opType;
-    int limit;
-    bool splitSearchMatchString;
+    EmailQuery::OpType opType = EmailQuery::OpAnd;
+    int limit = 0;
+    bool splitSearchMatchString = true;
 };
 
 EmailQuery::Private::Private()
     : important('0')
     , read('0')
     , attachment('0')
-    , opType(OpAnd)
-    , limit(0)
-    , splitSearchMatchString(true)
 {
 }
 
@@ -180,18 +178,18 @@ ResultIterator EmailQuery::exec()
     const QString dir = defaultLocation(QStringLiteral("email"));
     Xapian::Database db;
     try {
-        db = Xapian::Database(QFile::encodeName(dir).constData());
+        db = Xapian::Database(QFile::encodeName(dir).toStdString());
     } catch (const Xapian::DatabaseOpeningError &) {
-        qWarning() << "Xapian Database does not exist at " << dir;
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database does not exist at " << dir;
         return ResultIterator();
     } catch (const Xapian::DatabaseCorruptError &) {
-        qWarning() << "Xapian Database corrupted";
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database corrupted";
         return ResultIterator();
     } catch (const Xapian::DatabaseError &e) {
-        qWarning() << "Failed to open Xapian database:" << QString::fromStdString(e.get_description());
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Failed to open Xapian database:" << QString::fromStdString(e.get_description());
         return ResultIterator();
     } catch (...) {
-        qWarning() << "Random exception, but we do not want to crash";
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Random exception, but we do not want to crash";
         return ResultIterator();
     }
 
@@ -266,8 +264,8 @@ ResultIterator EmailQuery::exec()
     if (!d->collections.isEmpty()) {
         Xapian::Query query;
         for (Akonadi::Collection::Id id : qAsConst(d->collections)) {
-            QString c = QString::number(id);
-            Xapian::Query q = Xapian::Query('C' + c.toStdString());
+            const QString c = QString::number(id);
+            const Xapian::Query q = Xapian::Query('C' + c.toStdString());
 
             query = Xapian::Query(Xapian::Query::OP_OR, query, q);
         }
@@ -341,7 +339,8 @@ ResultIterator EmailQuery::exec()
         enquire.set_query(query);
 
         if (d->limit == 0) {
-            d->limit = 1000000;
+            //d->limit = 1000000;
+            d->limit = 100000;
         }
 
         Xapian::MSet mset = enquire.get_mset(0, d->limit);
@@ -350,7 +349,7 @@ ResultIterator EmailQuery::exec()
         iter.d->init(mset);
         return iter;
     } catch (const Xapian::Error &e) {
-        qWarning() << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
         return ResultIterator();
     }
 }
